@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::dzil_authors_by_bundle_count;
 
-our $DATE = '2015-12-07'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-01-18'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010;
 use strict;
@@ -21,11 +21,8 @@ $SPEC{'handle_cmd'} = {
 sub handle_cmd {
     my %args = @_;
 
-    App::lcpan::_set_args_default(\%args);
-    my $cpan = $args{cpan};
-    my $index_name = $args{index_name};
-
-    my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);
+    my $state = App::lcpan::_init(\%args, 'ro');
+    my $dbh = $state->{dbh};
 
     my $sql = "SELECT
   cpanid author,
@@ -62,7 +59,7 @@ App::lcpan::Cmd::dzil_authors_by_bundle_count - List authors ranked by number of
 
 =head1 VERSION
 
-This document describes version 0.02 of App::lcpan::Cmd::dzil_authors_by_bundle_count (from Perl distribution App-lcpan-CmdBundle-dzil), released on 2015-12-07.
+This document describes version 0.03 of App::lcpan::Cmd::dzil_authors_by_bundle_count (from Perl distribution App-lcpan-CmdBundle-dzil), released on 2016-01-18.
 
 =head1 FUNCTIONS
 
@@ -122,7 +119,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
