@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::dzil_bundles;
 
-our $DATE = '2015-12-07'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-01-18'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010;
 use strict;
@@ -23,16 +23,9 @@ $SPEC{handle_cmd} = {
         %App::lcpan::sort_modules_args,
     },
 };
-
 sub handle_cmd {
     my %args = @_;
 
-    App::lcpan::_set_args_default(\%args);
-    #my $cpan = $args{cpan};
-    #my $index_name = $args{index_name};
-
-    #my $dbh = App::lcpan::_connect_db('ro', $cpan, $index_name);
-
     my $res = App::lcpan::modules(%args, namespace=>'Dist::Zilla::PluginBundle');
 
     for (@{$res->[2]}) {
@@ -61,7 +54,7 @@ App::lcpan::Cmd::dzil_bundles - List Dist::Zilla bundles available on CPAN
 
 =head1 VERSION
 
-This document describes version 0.02 of App::lcpan::Cmd::dzil_bundles (from Perl distribution App-lcpan-CmdBundle-dzil), released on 2015-12-07.
+This document describes version 0.03 of App::lcpan::Cmd::dzil_bundles (from Perl distribution App-lcpan-CmdBundle-dzil), released on 2016-01-18.
 
 =head1 FUNCTIONS
 
@@ -92,10 +85,6 @@ Defaults to C<~/cpan>.
 
 Filter by distribution.
 
-=item * B<exact_match> => I<bool> (default: 0)
-
-Match query with exact module names.
-
 =item * B<index_name> => I<str> (default: "index.db")
 
 Filename of index.
@@ -149,7 +138,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
